==> distfun-0.3-1-src.zip: distfun/src/gwsupport/gwsupport.c <==

// Copyright (C) 2012 - Michael Baudin
// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

#include <limits.h>

#include "api_scilab.h"
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "warningmode.h"

#include "gwsupport.h" 

// 
// gwsupport_CheckSize --
//   Reports an error if the actual number of rows 
//   is not equal to the expected number of rows.
//   Reports an error if the actual number of columns 
//   is not equal to the expected number of columns.
//   Returns 0 if an error is detected, returns 1 if not error occurs.
// Arguments
//   fname (input) : the name of the Scilab function generating this error
//   ivar (input) : the index of the input variable
//   expected_nrows (input) : the expected number of rows
//   expected_ncols (input) : the expected number of columns
//   actual_nrows (input) : the actual number of rows
//   actual_ncols (input) : the actual number of columns
//
int gwsupport_CheckSize ( char * fname , int ivar , int expected_nrows , int expected_ncols , 
	int actual_nrows , int actual_ncols )
{
	if ( expected_nrows != actual_nrows )
	{
		Scierror(999,_("%s: Wrong size for input argument #%d: %d-by-%d matrix expected.\n"),
			fname, ivar , expected_nrows, expected_ncols );
		return 0;
	} 
	else if ( expected_ncols != actual_ncols )
	{
		Scierror(999,_("%s: Wrong size for input argument #%d: %d-by-%d matrix expected.\n"),
			fname, ivar , expected_nrows, expected_ncols );
		return 0;
	}
	return 1;
}


// 
// gwsupport_CreateLhsMatrixOfDoubles --
//   Creates a double matrix variable on the Left Hand Side at location ovar.
// Arguments
//   fname (input) : the name of the Scilab function generating this error
//   ovar (input) : the index of the output variable
//   _piRows (input) : the number of rows
//   _piCols (input) : the number of columns
//   _pdblReal (output) : the matrix to create
//
void gwsupport_CreateLhsMatrixOfDoubles ( int ovar , int _piRows , int _piCols , double ** _pdblReal )
{
	iAllocMatrixOfDouble ( Rhs + ovar , _piRows , _piCols , _pdblReal );
	LhsVar(ovar) = Rhs+ovar;
}

// Get a pointer to the doubles of a real matrix of doubles from input argument #ivar.
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// _piAddress(input): a data structure for the API
// _pdblReal (output): the data
// _piRows (output): the number of rows
// _piCols (output): the number of columns
//
// Description
// If we cannot get the matrix, produce an error and returns 0.
// Checks that the matrix is not complex.
// If we can get the matrix, returns 1.
// TODO : add _pvApiCtx in the calling sequence
//
int gwsupport_GetRealMatrixOfDoubles( char * fname, int ivar, double** _pdblReal, int * _piRows , int * _piCols )
{
	int iRet = 0;
	int iType = 0;
	int iComplex = 0;
	SciErr sciErr;
	int *_piAddress;

	sciErr = getVarAddressFromPosition(pvApiCtx, ivar, &_piAddress);
	if(sciErr.iErr)
	{
		printError(&sciErr, 0);
		return 0;
	}
	sciErr = getMatrixOfDouble(pvApiCtx, _piAddress, _piRows, _piCols, _pdblReal);
	if(sciErr.iErr)
	{
		printError(&sciErr, 0);
		return 0;
	}
	return 1;
}
// Check that a matrix of doubles is in a given range
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// _pdblReal (output): the data
// _piRows (output): the number of rows
// _piCols (output): the number of columns
// mindouble (input): the minimum value of the double.
// maxdouble (input): the maximum value of the double.
//
// Description
// If the matrix is not in the range [mindouble,maxdouble], produce an error and returns 0.
// If the matrix is OK, returns 1.
//
int gwsupport_CheckDoubleMatrixInRange (char *fname, int ivar, double* _pdblReal, int _piRows , int _piCols, 
	double mindouble, double maxdouble)
{
	int readFlag;
	double t;
	int i;

	for ( i=0 ; i < _piRows*_piCols; i++)
	{
		t = *(_pdblReal + i );
		readFlag = gwsupport_CheckDoubleInRange (fname, ivar, t, mindouble, maxdouble);
		if (readFlag==0)
		{
			return 0;
		}
	}
	return 1;
}
// Check that a matrix of doubles is greater or equal than a minimum bound
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// _pdblReal (output): the data
// _piRows (output): the number of rows
// _piCols (output): the number of columns
// mindouble (input): the minimum value of the double.
//
// Description
// If the matrix is >= mindouble, returns 1.
// If not, produce an error and returns 0.
//
int gwsupport_CheckDoubleMatrixGreaterOrEqual (char *fname, int ivar, double* _pdblReal, int _piRows , int _piCols, 
	double mindouble)
{
	double t;
	int i;
	int readFlag;

	for ( i=0 ; i < _piRows*_piCols; i++)
	{
		t = *(_pdblReal + i );
		readFlag = gwsupport_CheckDoubleGreaterOrEqual (fname, ivar, t, mindouble);
		if ( readFlag==0 )
		{
			return 0;
		}
	}
	return 1;
}

// Check that a double is greater or equal than a minimum bound
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// value (input): the number of columns
// mindouble (input): the minimum value of the double.
//
// Description
// If the matrix is not in range, produce an error and returns 0.
// If the matrix is OK, returns 1.
//
int gwsupport_CheckDoubleGreaterOrEqual (char *fname, int ivar, double value, double mindouble)
{
	if ( value < mindouble )
	{
		Scierror(204,_("%s: Wrong value for input argument #%d: Must be >= %f.\n"),fname, ivar, mindouble);
		return 0;
	}
	return 1;
}

// Check that a matrix of doubles is greater than a minimum bound
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// _pdblReal (output): the data
// _piRows (output): the number of rows
// _piCols (output): the number of columns
// mindouble (input): the minimum value of the double.
//
// Description
// If the matrix is > mindouble, returns 1.
// If not, produce an error and returns 0.
//
int gwsupport_CheckDoubleMatrixGreaterThan (char *fname, int ivar, double* _pdblReal, int _piRows , int _piCols, 
	double mindouble)
{
	double t;
	int i;

	for ( i=0 ; i < _piRows*_piCols; i++)
	{
		t = *(_pdblReal + i );
		if ( t <= mindouble )
		{
			Scierror(204,_("%s: Wrong value for input argument #%d: Must be > %f.\n"),fname, ivar, mindouble);
			return 0;
		}
	}
	return 1;
}

// Check that a double is in a given range
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// mydouble (input): the double to check
// mindouble (input): the minimum value of the double.
// maxdouble (input): the maximum value of the double.
//
// Description
// If myint is not in range, produce an error and returns 0.
// If myint is OK, returns 1.
//
int gwsupport_CheckDoubleInRange (char *fname, int ivar, double mydouble, double mindouble, double maxdouble)
{
	if ( mydouble > maxdouble )
	{
		Scierror(204,_("%s: Wrong value for input argument #%d: Must be < %f.\n"),fname, ivar, maxdouble);
		return 0;
	}
	if ( mydouble < mindouble )
	{
		Scierror(204,_("%s: Wrong value for input argument #%d: Must be > %f.\n"),fname, ivar, mindouble);
		return 0;
	}
	return 1;
}

// Get a matrix of doubles >=0
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// lrP (output): the data
// rowsP (output): the number of rows
// colsP (output): the number of columns
//
// Description
// If we cannot get the matrix, produce an error and returns 0.
// Checks that the matrix has entries greater or equal to 0.
//
int gwsupport_GetMatrixOfDoublesGreaterOrEqualThanZero( char * fname, int ivar , double** _pdblReal, int * rowsA , int * colsA	)
{
	int readFlag;

	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, ivar, _pdblReal, rowsA , colsA );
	if(readFlag==0)
	{
		return 0;
	}
	readFlag = gwsupport_CheckDoubleMatrixGreaterOrEqual (fname, ivar, *_pdblReal, *rowsA , *colsA, 0.);
	if (readFlag==0)
	{
		return 0;
	}
	return 1;
}

// Get a matrix of doubles >0
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// lrP (output): the data
// rowsP (output): the number of rows
// colsP (output): the number of columns
//
// Description
// If we cannot get the matrix, produce an error and returns 0.
// Checks that the matrix has entries greater or equal to 0.
//
int gwsupport_GetMatrixOfDoublesGreaterThanZero( char * fname, int ivar , double** _pdblReal, int * rowsA , int * colsA	)
{
	int readFlag;

	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, ivar, _pdblReal, rowsA , colsA );
	if(readFlag==0)
	{
		return 0;
	}
	readFlag = gwsupport_CheckDoubleMatrixGreaterThan (fname, ivar, *_pdblReal, *rowsA , *colsA, 0.);
	if (readFlag==0)
	{
		return 0;
	}
	return 1;
}
// 
// gwsupport_Double2IntegerArgument --
//   Compute if the given double is storable as an integer.
//   Returns 0 if an error is detected, returns 1 if no error occurs.
// Arguments
//   fname (input) : the name of the Scilab function generating this error
//   ivar (input) : the index of the input variable
//   dvalue (input) : the double value
//   ivalue (output) : the value to get
//
int gwsupport_Double2IntegerArgument ( char * fname , int ivar , double dvalue , int * ivalue )
{
	int readFlag;

	readFlag = gwsupport_CheckDoubleHasIntegerValue ( fname , ivar , dvalue );
	if ( readFlag == 0 ) 
	{
		return 0;
	}
	*ivalue = (int) dvalue;	
	return 1;
}
// 
// gwsupport_CheckDoubleMatrixHasIntegerValue --
//   Check if the given matrix of doubles has an integer value.
//   Returns 0 if an error is detected, returns 1 if no error occurs.
// Arguments
//   fname (input) : the name of the Scilab function generating this error
//   ivar (input) : the index of the input variable
//   dvalue (input) : the double value
//
int gwsupport_CheckDoubleMatrixHasIntegerValue ( char * fname , int ivar , double * p, int nrows , int ncols )
{
	int i;
	int readFlag;

	for ( i=0 ; i < nrows*ncols ; i++)
	{
		readFlag = gwsupport_CheckDoubleHasIntegerValue ( fname, ivar, *(p+i) );
		if ( readFlag == 0)
		{ 
			return 0;
		}
	}
	return 1;
}

// 
// gwsupport_CheckDoubleHasIntegerValue --
//   Check if the given double has an integer value.
//   Returns 0 if an error is detected, returns 1 if no error occurs.
// Arguments
//   fname (input) : the name of the Scilab function generating this error
//   ivar (input) : the index of the input variable
//   dvalue (input) : the double value
//
int gwsupport_CheckDoubleHasIntegerValue ( char * fname , int ivar , double dvalue )
{
	int ivalue;

	if ( dvalue > INT_MAX ) {
		Scierror(999,_("%s: Too large integer value in argument #%d: found %e while maximum value is %d.\n"),fname,ivar , dvalue , INT_MAX );
		return 0;
	}
	if ( dvalue < INT_MIN ) {
		Scierror(999,_("%s: Too large integer value in argument #%d: found %e while minimum value is %d.\n"),fname,ivar , dvalue , INT_MIN );
		return 0;
	}
	ivalue = (int) dvalue;
	// Now check that the double was really an integer
	if ( (double) ivalue != dvalue ) {
		Scierror(999,_("%s: Wrong integer in argument #%d: found %e which is different from the closest integer %d.\n"),fname,ivar , dvalue , ivalue );
		return 0;
	}
	
	return 1;
}

// 
// gwsupport_GetOneIntegerArgument --
//   Gets one integer number from the argument #ivar in the function fname.
//   Returns 0 if an error is detected, returns 1 if no error occurs.
// Arguments
//   fname (input) : the name of the Scilab function generating this error
//   ivar (input) : the index of the input variable
//   value (output) : the value to get
//
int gwsupport_GetOneIntegerArgument ( char * fname , int ivar , int * value )
{
	int _piRows;
	int _piCols;
	double * _pdblReal;
	int readFlag;
	
	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, ivar , &_pdblReal, &_piRows , &_piCols );
	if ( readFlag == 0 ) 
	{
		return 0;
	}
	readFlag = gwsupport_CheckSize ( fname , ivar , 1 , 1, _piRows , _piCols );
	if ( readFlag == 0 ) 
	{
		return 0;
	}
	readFlag = gwsupport_Double2IntegerArgument ( fname , ivar , _pdblReal[0] , value );
	if ( readFlag == 0 ) 
	{
		return 0;
	}
	return 1;
}

// Check that a double is greater than a minimum bound
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// value (input): the number of columns
// mindouble (input): the minimum value of the double.
//
// Description
// If the matrix is not in range, produce an error and returns 0.
// If the matrix is OK, returns 1.
//
int gwsupport_CheckDoubleGreaterThan (char *fname, int ivar, double value, double mindouble)
{
	if ( value <= mindouble )
	{
		Scierror(204,_("%s: Wrong value for input argument #%d: Must be > %f.\n"),fname, ivar, mindouble);
		return 0;
	}
	return 1;
}

// Prints a warning.
//
// Arguments
// message (input): the warning
//
// Description
// If the warning mode is ON, then prints the message.
//
void gwsupport_PrintWarning ( char * message ) 
{
	if ( getWarningMode() )
	{
		sciprint( _("WARNING: %s"), message );
	}
}

==> distfun-0.5-1-src.zip: distfun/src/gwsupport/gwsupport.c <==

// Copyright (C) 2012 - Michael Baudin
// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

#include <limits.h>

// From Scilab
#include "api_scilab.h"
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "warningmode.h"
#include "sciprint.h"

#include "gwsupport.h" 

// 
// gwsupport_CheckSize --
//   Reports an error if the actual number of rows 
//   is not equal to the expected number of rows.
//   Reports an error if the actual number of columns 
//   is not equal to the expected number of columns.
//   Returns 0 if an error is detected, returns 1 if not error occurs.
// Arguments
//   fname (input) : the name of the Scilab function generating this error
//   ivar (input) : the index of the input variable
//   expected_nrows (input) : the expected number of rows
//   expected_ncols (input) : the expected number of columns
//   actual_nrows (input) : the actual number of rows
//   actual_ncols (input) : the actual number of columns
//
int gwsupport_CheckSize ( char * fname , int ivar , int expected_nrows , int expected_ncols , 
	int actual_nrows , int actual_ncols )
{
	if ( expected_nrows != actual_nrows )
	{
		Scierror(999,_("%s: Wrong size for input argument #%d: %d-by-%d matrix expected.\n"),
			fname, ivar , expected_nrows, expected_ncols );
		return GWSUPPORT_ERROR;
	} 
	if ( expected_ncols != actual_ncols )
	{
		Scierror(999,_("%s: Wrong size for input argument #%d: %d-by-%d matrix expected.\n"),
			fname, ivar , expected_nrows, expected_ncols );
		return GWSUPPORT_ERROR;
	}
	return GWSUPPORT_OK;
}


// 
// gwsupport_AllocateLhsMatrixOfDoubles --
//   Creates a double matrix variable on the Left Hand Side at location ovar.
// Arguments
//   fname (input) : the name of the Scilab function generating this error
//   ovar (input) : the index of the output variable
//   _piRows (input) : the number of rows
//   _piCols (input) : the number of columns
//   _pdblReal (output) : the matrix to create
//
// Description
// This function allocates the memory for _pdblReal. 
// After calling gwsupport_AllocateLhsMatrixOfDoubles, the caller 
// should fill the array with values. 
//
int gwsupport_AllocateLhsMatrixOfDoubles ( int ovar , int _piRows , int _piCols , double ** _pdblReal )
{
	SciErr sciErr;
	sciErr = allocMatrixOfDouble(pvApiCtx, Rhs + ovar, _piRows, _piCols, _pdblReal);
	if(sciErr.iErr)
	{
		printError(&sciErr, 0);
		return GWSUPPORT_ERROR;
	}
	LhsVar(ovar) = Rhs+ovar;
	return GWSUPPORT_OK;
}

// Get a pointer to the doubles of a real matrix of doubles from input argument #ivar.
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// _piAddress(input): a data structure for the API
// _pdblReal (output): the data
// _piRows (output): the number of rows
// _piCols (output): the number of columns
//
// Description
// If we cannot get the matrix, produce an error and returns 0.
// Checks that the matrix is not complex.
// If we can get the matrix, returns 1.
// TODO : add _pvApiCtx in the calling sequence
//
int gwsupport_GetRealMatrixOfDoubles( char * fname, int ivar, double** _pdblReal, int * _piRows , int * _piCols )
{
	int iType = 0;
	int iComplex = 0;
	SciErr sciErr;
	int *_piAddress;

	sciErr = getVarAddressFromPosition(pvApiCtx, ivar, &_piAddress);
	if(sciErr.iErr)
	{
		printError(&sciErr, 0);
		return GWSUPPORT_ERROR;
	}
	sciErr = getMatrixOfDouble(pvApiCtx, _piAddress, _piRows, _piCols, _pdblReal);
	if(sciErr.iErr)
	{
		printError(&sciErr, 0);
		return GWSUPPORT_ERROR;
	}
	return GWSUPPORT_OK;
}
// Check that a matrix of doubles is in a given range
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// _pdblReal (output): the data
// _piRows (output): the number of rows
// _piCols (output): the number of columns
// mindouble (input): the minimum value of the double.
// maxdouble (input): the maximum value of the double.
//
// Description
// If the matrix is not in the range [mindouble,maxdouble], produce an error and returns 0.
// If the matrix is OK, returns 1.
//
int gwsupport_CheckDoubleMatrixInRange (char *fname, int ivar, double* _pdblReal, int _piRows , int _piCols, 
	double mindouble, double maxdouble)
{
	int readFlag;
	double t;
	int i;

	for ( i=0 ; i < _piRows*_piCols; i++)
	{
		t = *(_pdblReal + i );
		readFlag = gwsupport_CheckDoubleInRange (fname, ivar, t, mindouble, maxdouble);
		if (readFlag==0)
		{
			return GWSUPPORT_ERROR;
		}
	}
	return GWSUPPORT_OK;
}
// Check that a matrix of doubles is greater or equal than a minimum bound
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// _pdblReal (output): the data
// _piRows (output): the number of rows
// _piCols (output): the number of columns
// mindouble (input): the minimum value of the double.
//
// Description
// If the matrix is >= mindouble, returns 1.
// If not, produce an error and returns 0.
//
int gwsupport_CheckDoubleMatrixGreaterOrEqual (char *fname, int ivar, double* _pdblReal, int _piRows , int _piCols, 
	double mindouble)
{
	double t;
	int i;
	int readFlag;

	for ( i=0 ; i < _piRows*_piCols; i++)
	{
		t = *(_pdblReal + i );
		readFlag = gwsupport_CheckDoubleGreaterOrEqual (fname, ivar, t, mindouble);
		if ( readFlag==0 )
		{
			return GWSUPPORT_ERROR;
		}
	}
	return GWSUPPORT_OK;
}

// Check that a double is greater or equal than a minimum bound
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// value (input): the number of columns
// mindouble (input): the minimum value of the double.
//
// Description
// If the matrix is not in range, produce an error and returns 0.
// If the matrix is OK, returns 1.
//
int gwsupport_CheckDoubleGreaterOrEqual (char *fname, int ivar, double value, double mindouble)
{
	if ( value < mindouble )
	{
		Scierror(204,_("%s: Wrong value for input argument #%d: Must be >= %e.\n"),fname, ivar, mindouble);
		return GWSUPPORT_ERROR;
	}
	return GWSUPPORT_OK;
}

// Check that a matrix of doubles is greater than a minimum bound
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// _pdblReal (output): the data
// _piRows (output): the number of rows
// _piCols (output): the number of columns
// mindouble (input): the minimum value of the double.
//
// Description
// If the matrix is > mindouble, returns 1.
// If not, produce an error and returns 0.
//
int gwsupport_CheckDoubleMatrixGreaterThan (char *fname, int ivar, double* _pdblReal, int _piRows , int _piCols, 
	double mindouble)
{
	double t;
	int i;

	for ( i=0 ; i < _piRows*_piCols; i++)
	{
		t = *(_pdblReal + i );
		if ( t <= mindouble )
		{
			Scierror(204,_("%s: Wrong value for input argument #%d: Must be > %e.\n"),fname, ivar, mindouble);
			return GWSUPPORT_ERROR;
		}
	}
	return GWSUPPORT_OK;
}

// Check that a double is in a given range
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// mydouble (input): the double to check
// mindouble (input): the minimum value of the double.
// maxdouble (input): the maximum value of the double.
//
// Description
// If myint is not in range, produce an error and returns 0.
// If myint is OK, returns 1.
//
int gwsupport_CheckDoubleInRange (char *fname, int ivar, double mydouble, double mindouble, double maxdouble)
{
	if ( mydouble > maxdouble )
	{
		Scierror(204,_("%s: Wrong value for input argument #%d: Must be < %e.\n"),fname, ivar, maxdouble);
		return GWSUPPORT_ERROR;
	}
	if ( mydouble < mindouble )
	{
		Scierror(204,_("%s: Wrong value for input argument #%d: Must be > %e.\n"),fname, ivar, mindouble);
		return GWSUPPORT_ERROR;
	}
	return GWSUPPORT_OK;
}

// Get a matrix of doubles >=0
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// lrP (output): the data
// rowsP (output): the number of rows
// colsP (output): the number of columns
//
// Description
// If we cannot get the matrix, produce an error and returns 0.
// Checks that the matrix has entries greater or equal to 0.
//
int gwsupport_GetMatrixOfDoublesGreaterOrEqualThanZero( char * fname, int ivar , double** _pdblReal, int * rowsA , int * colsA	)
{
	int readFlag;

	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, ivar, _pdblReal, rowsA , colsA );
	if(readFlag==0)
	{
		return GWSUPPORT_ERROR;
	}
	readFlag = gwsupport_CheckDoubleMatrixGreaterOrEqual (fname, ivar, *_pdblReal, *rowsA , *colsA, 0.);
	if (readFlag==0)
	{
		return GWSUPPORT_ERROR;
	}
	return GWSUPPORT_OK;
}

// Get a matrix of doubles >0
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// lrP (output): the data
// rowsP (output): the number of rows
// colsP (output): the number of columns
//
// Description
// If we cannot get the matrix, produce an error and returns 0.
// Checks that the matrix has entries greater or equal to 0.
//
int gwsupport_GetMatrixOfDoublesGreaterThanZero( char * fname, int ivar , double** _pdblReal, int * rowsA , int * colsA	)
{
	int readFlag;

	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, ivar, _pdblReal, rowsA , colsA );
	if(readFlag==0)
	{
		return GWSUPPORT_ERROR;
	}
	readFlag = gwsupport_CheckDoubleMatrixGreaterThan (fname, ivar, *_pdblReal, *rowsA , *colsA, 0.);
	if (readFlag==0)
	{
		return GWSUPPORT_ERROR;
	}
	return GWSUPPORT_OK;
}
// 
// gwsupport_Double2IntegerArgument --
//   Compute if the given double is storable as an integer.
//   Returns 0 if an error is detected, returns 1 if no error occurs.
// Arguments
//   fname (input) : the name of the Scilab function generating this error
//   ivar (input) : the index of the input variable
//   dvalue (input) : the double value
//   ivalue (output) : the value to get
//
int gwsupport_Double2IntegerArgument ( char * fname , int ivar , double dvalue , int * ivalue )
{
	int readFlag;

	readFlag = gwsupport_CheckDoubleHasIntegerValue ( fname , ivar , dvalue );
	if ( readFlag == 0 ) 
	{
		return GWSUPPORT_ERROR;
	}
	*ivalue = (int) dvalue;	
	return GWSUPPORT_OK;
}
// 
// gwsupport_CheckDoubleMatrixHasIntegerValue --
//   Check if the given matrix of doubles has an integer value.
//   Returns 0 if an error is detected, returns 1 if no error occurs.
// Arguments
//   fname (input) : the name of the Scilab function generating this error
//   ivar (input) : the index of the input variable
//   dvalue (input) : the double value
//
int gwsupport_CheckDoubleMatrixHasIntegerValue ( char * fname , int ivar , double * p, int nrows , int ncols )
{
	int i;
	int readFlag;

	for ( i=0 ; i < nrows*ncols ; i++)
	{
		readFlag = gwsupport_CheckDoubleHasIntegerValue ( fname, ivar, *(p+i) );
		if ( readFlag == 0)
		{ 
			return GWSUPPORT_ERROR;
		}
	}
	return GWSUPPORT_OK;
}

// 
// gwsupport_CheckDoubleHasIntegerValue --
//   Check if the given double has an integer value.
//   Returns 0 if an error is detected, returns 1 if no error occurs.
// Arguments
//   fname (input) : the name of the Scilab function generating this error
//   ivar (input) : the index of the input variable
//   dvalue (input) : the double value
//
int gwsupport_CheckDoubleHasIntegerValue ( char * fname , int ivar , double dvalue )
{
	int ivalue;

	if ( dvalue > INT_MAX ) {
		Scierror(999,_("%s: Too large integer value in argument #%d: found %e while maximum value is %d.\n"),fname,ivar , dvalue , INT_MAX );
		return GWSUPPORT_ERROR;
	}
	if ( dvalue < INT_MIN ) {
		Scierror(999,_("%s: Too large integer value in argument #%d: found %e while minimum value is %d.\n"),fname,ivar , dvalue , INT_MIN );
		return GWSUPPORT_ERROR;
	}
	ivalue = (int) dvalue;
	// Now check that the double was really an integer
	if ( (double) ivalue != dvalue ) {
		Scierror(999,_("%s: Wrong integer in argument #%d: found %e which is different from the closest integer %d.\n"),fname,ivar , dvalue , ivalue );
		return GWSUPPORT_ERROR;
	}
	
	return GWSUPPORT_OK;
}

// 
// gwsupport_GetOneIntegerArgument --
//   Gets one integer number from the argument #ivar in the function fname.
//   Returns 0 if an error is detected, returns 1 if no error occurs.
// Arguments
//   fname (input) : the name of the Scilab function generating this error
//   ivar (input) : the index of the input variable
//   value (output) : the value to get
//
int gwsupport_GetOneIntegerArgument ( char * fname , int ivar , int * value )
{
	int _piRows;
	int _piCols;
	double * _pdblReal;
	int readFlag;
	
	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, ivar , &_pdblReal, &_piRows , &_piCols );
	if ( readFlag == 0 ) 
	{
		return GWSUPPORT_ERROR;
	}
	readFlag = gwsupport_CheckSize ( fname , ivar , 1 , 1, _piRows , _piCols );
	if ( readFlag == 0 ) 
	{
		return GWSUPPORT_ERROR;
	}
	readFlag = gwsupport_Double2IntegerArgument ( fname , ivar , _pdblReal[0] , value );
	if ( readFlag == 0 ) 
	{
		return GWSUPPORT_ERROR;
	}
	return GWSUPPORT_OK;
}

// Check that a double is greater than a minimum bound
//
// Arguments
// fname (input): the name of the function
// ivar (input): the index of the input argument
// value (input): the number of columns
// mindouble (input): the minimum value of the double.
//
// Description
// If the matrix is not in range, produce an error and returns 0.
// If the matrix is OK, returns 1.
//
int gwsupport_CheckDoubleGreaterThan (char *fname, int ivar, double value, double mindouble)
{
	if ( value <= mindouble )
	{
		Scierror(204,_("%s: Wrong value for input argument #%d: Must be > %e.\n"),fname, ivar, mindouble);
		return GWSUPPORT_ERROR;
	}
	return GWSUPPORT_OK;
}

// Prints a warning.
//
// Arguments
// message (input): the warning
//
// Description
// If the warning mode is ON, then prints the message.
//
void gwsupport_PrintWarning ( char * message ) 
{
	if ( getWarningMode() )
	{
		sciprint( _("WARNING: %s"), message );
	}
}

// Get scalar double
int gwsupport_GetScalarDouble( char * fname, int ivar , double* lrA )
{
	int m, n;
	int readFlag;
	double* _pdblReal;

	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, ivar, &_pdblReal, &m, &n);
	*lrA = *_pdblReal;
	if ( readFlag == 0)
	{ 
		return GWSUPPORT_ERROR;
	}
	readFlag = gwsupport_CheckSize ( fname, ivar, 1, 1, m, n);
	if ( readFlag == 0)
	{ 
		return GWSUPPORT_ERROR;
	}
	return GWSUPPORT_OK;
}
// Get scalar string
int gwsupport_GetScalarString( char * fname, int ivar , char** mystring )
{
	int *_piAddress;
	int iRet = 0;
	SciErr sciErr;

	sciErr = getVarAddressFromPosition(pvApiCtx, ivar, &_piAddress);
	if(sciErr.iErr)
	{
		printError(&sciErr, 0);
		return GWSUPPORT_ERROR;
	}
	iRet = getAllocatedSingleString(pvApiCtx, _piAddress, mystring);
	if (iRet)
	{
        Scierror(999,_("%s: Wrong type for input argument #%d: Single string expected.\n" ), fname,ivar);
		return GWSUPPORT_ERROR;
	}
	return GWSUPPORT_OK;
}
